//console.cpp

#include <cssysdef.h>
#include "console.h"

void cimConsole::ExecCallback::Execute(const char *cmd)
{
	//we call the python interpreter:
	python->RunText(cmd);

}
bool cimConsole::ExecCallback::InitPython(iObjectRegistry *obj_reg)
{
	
	 python = csQueryRegistryOrLoad<iScript> (obj_reg,
	  "crystalspace.script.python");
	 if (!python)
  {
    csReport (obj_reg,
	    	CS_REPORTER_SEVERITY_ERROR, "cim.console",
		"Can't load the python script module!");
    return false;
  }
	 python->RunText("from cspace import *");
		

	if (!python->LoadModule("cshelper") )
	return false;

	return true;

}
bool cimConsole::Initialize(iObjectRegistry* obj_reg)
{
	object_reg = obj_reg;

	conout = CS_QUERY_REGISTRY(obj_reg, iConsoleOutput);

  if (!conout)
  {
    csReport (object_reg,
	    	CS_REPORTER_SEVERITY_ERROR, "cim.console",
		"Can't load the output console!");
    return false;
  }
  conin = CS_QUERY_REGISTRY(object_reg,iConsoleInput);
  if (!conin)
  {
    csReport (object_reg,
	    	CS_REPORTER_SEVERITY_ERROR, "cim.console",
		"Can't load the input console!");
    return false;
  }
 

  conin->Bind (conout);
  conin->SetPrompt ("cim:");
  ExecCallback* cb = new ExecCallback ();
  conin->SetExecuteCallback (cb);
  if(!cb->InitPython(object_reg)) return false;
  cb->DecRef ();
  conout->SetVisible (false);

  return true;
}

bool cimConsole::HandleEvent(iEvent &ev)
{

	return conin->HandleEvent(ev);

}

void cimConsole::Hide()
{
	visible= false;
	conout->SetVisible(false);
}

void cimConsole::Show()
{
	visible= true;
	conout->SetVisible(true);
}

void cimConsole::Toggle()
{
	visible=!visible;
	conout->SetVisible(visible);

}

bool cimConsole::IsVisible()
{
	return visible;

}